@@ -1225,3 +1225,10 @@ class TestExploitSamples(object):
         expected = ['Launching: http: -J-jar http://192.168.1.100/exploit.jar none']
 
         self.do_perform_test(caplog, sample, expected)
+
+    def test_CVE_2021_40444(self, caplog):
+        sample   = os.path.join(self.exploits_path, "test-CVE-2021-40444.html")
+        expected = ["[Microsoft XMLHTTP ActiveX] open('GET', 'http://127.0.0.1/calc.cab', False)",
+                    "[Microsoft XMLHTTP ActiveX] Fetching from URL http://127.0.0.1/calc.cab (method: GET)"]
+
+        self.do_perform_test(caplog, sample, expected)
