@@ -402,6 +402,11 @@ class TestMiscSamplesIE(object):
                     'screenX: 0',
                     'confirm: true']
 
+    def test_testMicrosoftXMLHTTPEvent9(self, caplog):
+        sample   = os.path.join(self.misc_path, "testMicrosoftXMLHTTPEvent9.html")
+        expected = ["[Window] Alert Text: Request completed"]
+        self.do_perform_test(caplog, sample, expected)
+
     def test_testCurrentScript(self, caplog):
         sample   = os.path.join(self.misc_path, "testCurrentScript.html")
         expected = ["[Window] Alert Text: This page has scripts",
@@ -941,8 +946,11 @@ class TestMiscSamplesIE(object):
     def test_testHTMLTableElement3(self, caplog):
         sample   = os.path.join(self.misc_path, "testHTMLTableElement3.html")
         expected = ['tHead: [object HTMLTableSectionElement]',
+                    'tHead row 0 sectionRowIndex: 0',
                     'tFoot: [object HTMLTableSectionElement]',
                     'caption: [object HTMLTableCaptionElement]',
+                    'Row 0 rowIndex = 0',
+                    'Row 1 rowIndex = 1',
                     'row: [object HTMLTableRowElement]',
                     'tBodies: [object HTMLCollection]',
                     'cell: [object HTMLTableCellElement]',
@@ -1079,7 +1087,10 @@ class TestMiscSamplesIE(object):
                     'error: null',
                     'mediaKeys: null',
                     'networkState: 1',
+                    'audioTracks length: 0',
+                    'textTracks length: 0',
                     'sinkId:',
+                    'buffered length: 0',
                     'paused: true']
 
         self.do_perform_test(caplog, sample, expected)
@@ -1402,3 +1413,21 @@ class TestMiscSamplesIE(object):
                     "[Window] Alert Text: document.msVisibilityState: visible"]
 
         self.do_perform_test(caplog, sample, expected)
+
+    def test_testSplitText(self, caplog):
+        sample   = os.path.join(self.misc_path, "testSplitText.html")
+        expected = ["p.childNodes.length before splitText: 1",
+                    "foobar value after splitText: foo",
+                    "bar value: bar",
+                    "p.childNodes.length after splitText: 2"]
+
+        self.do_perform_test(caplog, sample, expected)
+
+    def test_testNormalize(self, caplog):
+        sample   = os.path.join(self.misc_path, "testNormalize.html")
+        expected = ["[Before normalize] wrapper.childNodes.length: 6",
+                    "[After normalize] wrapper.childNodes.length: 3",
+                    "[After normalize] wrapper.childNodes[0].textContent: Part 1 Part 2 Part 3",
+                    "[After normalize] wrapper.childNodes[2].textContent: Part 4 Part 5"]
+
+        self.do_perform_test(caplog, sample, expected)
