@@ -4,7 +4,7 @@ import logging
 log = logging.getLogger("Thug")
 
 
-def GetVariable(self, arg):
+def GetVariable(self, arg): # pylint:disable=unused-argument
     if arg in ("$version", ):
         version = ['0', '0', '0', '0']
         idx     = 0
@@ -13,6 +13,6 @@ def GetVariable(self, arg):
             version[idx] = p
             idx += 1
 
-        return "WIN %s" % (','.join(version))
+        return f"WIN {','.join(version)}"
 
     return "" # pragma: no cover
