@@ -13,8 +13,8 @@ def PrintSnapshot(self, SnapshotPath = '', CompressedPath = ''):
     if CompressedPath:
         self.CompressedPath = CompressedPath
 
-    msg = '[Microsoft Access Snapshot Viewer ActiveX] SnapshotPath : %s, CompressedPath: %s' % (self.SnapshotPath,
-                                                                                                self.CompressedPath, )
+    msg = f"[Microsoft Access Snapshot Viewer ActiveX] SnapshotPath : {self.SnapshotPath}, CompressedPath: {self.CompressedPath}"
+
     log.ThugLogging.add_behavior_warn(msg, 'CVE-2008-2463')
     log.ThugLogging.log_exploit_event(self._window.url,
                                       "Microsoft Access Snapshot Viewer ActiveX",
@@ -31,5 +31,5 @@ def PrintSnapshot(self, SnapshotPath = '', CompressedPath = ''):
 
     try:
         self._window._navigator.fetch(url, redirect_type = "CVE-2008-2463")
-    except Exception:
+    except Exception: # pragma: no cover,pylint:disable=broad-except
         log.ThugLogging.add_behavior_warn('[Microsoft Access Snapshot Viewer ActiveX] Fetch failed')
