@@ -6,7 +6,7 @@ import logging
 log = logging.getLogger("Thug")
 
 
-def InternalTuneIn(self, arg0, arg1, arg2, arg3, arg4):
+def InternalTuneIn(self, arg0, arg1, arg2, arg3, arg4): # pylint:disable=unused-argument
     if len(arg0) > 248:
         log.ThugLogging.log_exploit_event(self._window.url,
                                           "StreamAudio ChainCast VMR Client Proxy ActiveX",
