@@ -17,9 +17,9 @@ def installAppMgr(self, url):
                                      )
 
     log.ThugLogging.log_classifier("exploit", log.ThugLogging.url, "CVE-2008-4388")
-    log.ThugLogging.add_behavior_warn("[Symantec AppStream LaunchObj ActiveX] Fetching from URL %s" % (url, ))
+    log.ThugLogging.add_behavior_warn(f"[Symantec AppStream LaunchObj ActiveX] Fetching from URL {url}")
 
     try:
         self._window._navigator.fetch(url, redirect_type = "CVE-2008-4388")
-    except Exception:
+    except Exception: # pylint:disable=broad-except
         log.ThugLogging.add_behavior_warn('[Symantec AppStream LaunchObj ActiveX] Fetch failed')
