@@ -16,11 +16,15 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 # MA  02111-1307  USA
 
+import types
+import operator
 import re
 import base64
 import logging
-import six.moves.urllib.parse as urlparse
-import six
+
+from urllib.parse import urljoin
+from urllib.parse import unquote
+
 import bs4
 
 from bs4.element import NavigableString
@@ -84,8 +88,8 @@ class DFT:
     def __init__(self, window, **kwds):
         self.window            = window
         self.window.doc.DFT    = self
-        self.anchors           = list()
-        self.forms             = kwds['forms'] if 'forms' in kwds else list()
+        self.anchors           = []
+        self.forms             = kwds['forms'] if 'forms' in kwds else []
         self._context          = None
         log.DFT                = self
 
@@ -93,7 +97,7 @@ class DFT:
         self._init_pyhooks()
 
     def _init_events(self):
-        self.listeners = list()
+        self.listeners = []
 
         # Events are handled in the same order they are inserted in this list
         self.handled_events = ['load', 'mousemove']
@@ -109,10 +113,13 @@ class DFT:
         if hooks is None:
             return
 
+        get_method_function = operator.attrgetter("__func__")
+        get_method_self = operator.attrgetter("__self__")
+
         for label, hook in hooks.items():
-            name   = "{}_hook".format(label)
-            _hook = six.get_method_function(hook) if six.get_method_self(hook) else hook
-            method = six.create_bound_method(_hook, DFT)
+            name   = f"{label}_hook"
+            _hook = get_method_function(hook) if get_method_self(hook) else hook
+            method = types.MethodType(_hook, DFT)
             setattr(self, name, method)
 
     @property
@@ -175,7 +182,7 @@ class DFT:
             self.window.event = evtObject
             handler()
         else:
-            handler(evtObject)
+            handler.apply(evtObject.currentTarget)
 
     def handle_window_event(self, onevt):
         if onevt not in self.handled_on_events:
@@ -188,16 +195,27 @@ class DFT:
             return
 
         handler = getattr(self.window, onevt, None)
-        if not handler:
+
+        if handler:
+            if (self.window, onevt[2:], handler) in self.dispatched_events:
+                return
+
+            self.dispatched_events.add((self.window, onevt[2:], handler))
+
+            evtObject = self.get_evtObject(self.window, onevt[2:])
+            self.run_event_handler(handler, evtObject)
             return
 
-        if (self.window, onevt[2:], handler) in self.dispatched_events:
-            return
+        with self.context as ctx:
+            handler_type = ctx.eval(f"typeof window.{onevt}")
+            if handler_type in ('function', ): # pragma: no cover
+                handler = ctx.eval(f"window.{onevt}")
 
-        self.dispatched_events.add((self.window, onevt[2:], handler))
+                if (self.window, onevt[2:], handler) in self.dispatched_events:
+                    return
 
-        evtObject = self.get_evtObject(self.window, onevt[2:])
-        self.run_event_handler(handler, evtObject)
+                handler.call()
+                self.dispatched_events.add((self.window, onevt[2:], handler))
 
     def handle_document_event(self, onevt):
         if onevt not in self.handled_on_events:
@@ -211,7 +229,7 @@ class DFT:
         if '_listeners' not in self.window.doc.tag.__dict__:
             return # pragma: no cover
 
-        for (eventType, listener, capture) in self.window.doc.tag._listeners:  # pragma: no cover
+        for (eventType, listener, capture) in self.window.doc.tag._listeners:  # pragma: no cover,pylint:disable=unused-variable
             if eventType not in (onevt[2:], ):
                 continue
 
@@ -246,7 +264,7 @@ class DFT:
     def set_event_handler_attributes(self, elem):
         try:
             attrs = elem.attrs
-        except Exception:
+        except Exception: # pylint:disable=broad-except
             return
 
         if 'language' in list(attrs.keys()) and not attrs['language'].lower() in ('javascript', ):
@@ -261,14 +279,14 @@ class DFT:
     def attach_event(self, elem, evt, h):
         handler = None
 
-        if isinstance(h, six.string_types):
+        if isinstance(h, str):
             handler = self.build_event_handler(self.context, h)
         elif log.JSEngine.isJSFunction(h):
             handler = h
         else: # pragma: no cover
             try:
                 handler = getattr(self.context.locals, h, None)
-            except Exception:
+            except Exception: # pylint:disable=broad-except
                 handler = None
 
         if not handler: # pragma: no cover
@@ -303,15 +321,15 @@ class DFT:
     def javaUserAgent(self):
         javaplugin = log.ThugVulnModules._javaplugin.split('.')
         last = javaplugin.pop()
-        version = '%s_%s' % ('.'.join(javaplugin), last)
+        version = f"{'.'.join(javaplugin)}_{last}"
         return log.ThugOpts.Personality.javaUserAgent % (version, )
 
     @property
     def javaWebStartUserAgent(self):
         javaplugin = log.ThugVulnModules._javaplugin.split('.')
         last = javaplugin.pop()
-        version = '%s_%s' % ('.'.join(javaplugin), last)
-        return "JNLP/6.0 javaws/%s (b04) Java/%s" % (version, version, )
+        version = f"{'.'.join(javaplugin)}_{last}"
+        return f"JNLP/6.0 javaws/{version} (b04) Java/{version}"
 
     @property
     def shockwaveFlash(self):
@@ -332,7 +350,7 @@ class DFT:
     def _handle_jnlp(self, data, headers, params):
         try:
             soup = bs4.BeautifulSoup(data, "lxml")
-        except Exception as e: # pragma: no cover
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.info("[ERROR][_handle_jnlp] %s", str(e))
             return
 
@@ -345,7 +363,7 @@ class DFT:
         log.ThugLogging.add_behavior_warn(description = '[JNLP Detected]', method = 'Dynamic Analysis')
 
         for param in soup.find_all('param'):
-            log.ThugLogging.add_behavior_warn(description = '[JNLP] %s' % (param, ), method = 'Dynamic Analysis')
+            log.ThugLogging.add_behavior_warn(description = f'[JNLP] {param}', method = 'Dynamic Analysis')
             self._check_jnlp_param(param)
 
         jars = soup.find_all("jar")
@@ -356,13 +374,13 @@ class DFT:
 
         for jar in jars:
             try:
-                url = "%s%s" % (codebase, jar.attrs['href'], )
+                url = f"{codebase}{jar.attrs['href']}"
                 self.window._navigator.fetch(url, headers = headers, redirect_type = "JNLP", params = params)
-            except Exception as e: # pragma: no cover
+            except Exception as e: # pragma: no cover,pylint:disable=broad-except
                 log.info("[ERROR][_handle_jnlp] %s", str(e))
 
     def do_handle_params(self, _object):
-        params = dict()
+        params = {}
 
         for child in _object.find_all():
             name = getattr(child, 'name', None)
@@ -386,7 +404,7 @@ class DFT:
         if hook:
             hook(params) # pylint:disable=not-callable
 
-        headers = dict()
+        headers = {}
         headers['Connection'] = 'keep-alive'
 
         if 'type' in params:
@@ -415,7 +433,7 @@ class DFT:
                                              headers = headers,
                                              redirect_type = "params",
                                              params = params)
-            except Exception as e:
+            except Exception as e: # pylint:disable=broad-except
                 log.info("[ERROR][do_handle_params] %s", str(e))
 
         for key, value in params.items():
@@ -436,11 +454,11 @@ class DFT:
 
                 if response:
                     self._handle_jnlp(response.content, headers, params)
-            except Exception as e:
+            except Exception as e: # pylint:disable=broad-except
                 log.info("[ERROR][do_handle_params] %s", str(e))
 
         for p in ('source', 'data', 'archive' ):
-            handler = getattr(self, "do_handle_params_{}".format(p), None)
+            handler = getattr(self, f"do_handle_params_{p}", None)
             if handler:
                 handler(params, headers) # pylint:disable=not-callable
 
@@ -455,7 +473,7 @@ class DFT:
                                          headers = headers,
                                          redirect_type = "params",
                                          params = params)
-        except Exception as e:
+        except Exception as e: # pylint:disable=broad-except
             log.info("[ERROR][do_params_fetch] %s", str(e))
 
     def do_handle_params_source(self, params, headers):
@@ -475,7 +493,7 @@ class DFT:
             return
 
         if 'codebase' in params:
-            archive = urlparse.urljoin(params['codebase'], params['archive'])
+            archive = urljoin(params['codebase'], params['archive'])
         else:
             archive = params['archive']
 
@@ -504,7 +522,7 @@ class DFT:
                 self.window._navigator.fetch(codebase,
                                              redirect_type = "object codebase",
                                              params = params)
-            except Exception as e: # pragma: no cover
+            except Exception as e: # pragma: no cover,pylint:disable=broad-except
                 log.info("[ERROR][handle_object] %s", str(e))
 
         if data and not data.startswith('data:'):
@@ -515,7 +533,7 @@ class DFT:
                 self.window._navigator.fetch(data,
                                              redirect_type = "object data",
                                              params = params)
-            except Exception as e:
+            except Exception as e: # pylint:disable=broad-except
                 log.info("[ERROR][handle_object] %s", str(e))
 
         if not log.ThugOpts.Personality.isIE():
@@ -538,7 +556,7 @@ class DFT:
                 log.info("[ERROR][handle_object] %s", str(e))
 
     def _get_script_for_event_params(self, attr_event):
-        result = list()
+        result = []
         params = attr_event.split('(')
 
         if len(params) > 1:
@@ -559,11 +577,11 @@ class DFT:
         if 'playstatechange' in attr_event.lower() and params:
             with self.context as ctx:
                 newState = params.pop()
-                ctx.eval("%s = 0;" % (newState.strip(), ))
+                ctx.eval(f"{newState.strip()} = 0;")
                 try:
                     oldState = params.pop()
-                    ctx.eval("%s = 3;" % (oldState.strip(), )) # pragma: no cover
-                except Exception as e:
+                    ctx.eval(f"{oldState.strip()} = 3;") # pragma: no cover
+                except Exception as e: # pylint:disable=broad-except
                     log.info("[ERROR][_handle_script_for_event] %s", str(e))
 
     def get_script_handler(self, script):
@@ -579,14 +597,14 @@ class DFT:
 
         try:
             _language = language.lower().split('/')[-1]
-        except Exception: # pragma: no cover
+        except Exception: # pragma: no cover,pylint:disable=broad-except
             log.warning("[SCRIPT] Unhandled script type: %s", language)
             return None
 
         if _language in ("script", ): # pragma: no cover
             _language = "javascript"
 
-        return getattr(self, "handle_{}".format(_language), None)
+        return getattr(self, f"handle_{_language}", None)
 
     def handle_jscript_compact(self, script):
         log.ThugLogging.log_classifier("jscript", log.ThugLogging.url, 'JScript.Compact')
@@ -637,7 +655,7 @@ class DFT:
         try:
             s.text = response.text
             return True
-        except Exception: # pragma: no cover
+        except Exception: # pragma: no cover,pylint:disable=broad-except
             return self.handle_external_javascript_text_last_attempt(s, response)
 
     def handle_external_javascript_text_last_attempt(self, s, response): # pragma: no cover
@@ -652,7 +670,7 @@ class DFT:
 
         try:
             s.text = js.decode(enc['encoding'])
-        except Exception as e:
+        except Exception as e: # pylint:disable=broad-except
             log.warning("[ERROR][handle_external_javascript_text_last_attempt] %s", str(e))
             return False
 
@@ -685,7 +703,7 @@ class DFT:
 
         try:
             response = self.window._navigator.fetch(src, redirect_type = "script src")
-        except Exception as e:
+        except Exception as e: # pylint:disable=broad-except
             log.info("[ERROR][handle_external_javascript] %s", str(e))
             return
 
@@ -709,7 +727,7 @@ class DFT:
         if not log.ThugOpts.features_logging:
             return
 
-        m = getattr(log.ThugLogging.Features, "increase_{}_javascript_count".format(provenance), None)
+        m = getattr(log.ThugLogging.Features, f"increase_{provenance}_javascript_count", None)
         if m:
             m()
 
@@ -717,11 +735,11 @@ class DFT:
         if not log.ThugOpts.features_logging:
             return
 
-        m = getattr(log.ThugLogging.Features, "add_{}_{}_characters_count".format(provenance, type_), None)
+        m = getattr(log.ThugLogging.Features, f"add_{provenance}_{type_}_characters_count", None)
         if m:
             m(len(code))
 
-        m = getattr(log.ThugLogging.Features, "add_{}_{}_whitespaces_count".format(provenance, type_), None)
+        m = getattr(log.ThugLogging.Features, f"add_{provenance}_{type_}_whitespaces_count", None)
         if m:
             m(len([a for a in code if a.isspace()]))
 
@@ -735,7 +753,7 @@ class DFT:
             if not count:
                 continue
 
-            m = getattr(log.ThugLogging.Features, "add_{}_string_count".format(s), None)
+            m = getattr(log.ThugLogging.Features, f"add_{s}_string_count", None)
             if m:
                 m(count)
 
@@ -796,7 +814,7 @@ class DFT:
         try:
             log.ThugLogging.log_file(text, url, sampletype = 'VBS')
             log.VBSClassifier.classify(url, text)
-        except Exception as e: # pragma: no cover
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.info("[ERROR][handle_vbscript_text] %s", str(e))
 
         hook = getattr(self, "do_handle_vbscript_text_hook", None)
@@ -811,7 +829,7 @@ class DFT:
                     log.ThugLogging.Features.increase_url_count()
 
                 self.window._navigator.fetch(url, redirect_type = "VBS embedded URL")
-        except Exception as e:
+        except Exception as e: # pylint:disable=broad-except
             log.info("[ERROR][handle_vbscript_text] %s", str(e))
 
     def handle_vbs(self, script):
@@ -820,23 +838,23 @@ class DFT:
     def handle_visualbasic(self, script):
         self.handle_vbscript(script)
 
-    def handle_noscript(self, script):
+    def handle_noscript(self, script): # pylint:disable=unused-argument
         if log.ThugOpts.features_logging:
             log.ThugLogging.Features.increase_noscript_count()
 
-    def handle_html(self, html):
+    def handle_html(self, html): # pylint:disable=unused-argument
         if log.ThugOpts.features_logging:
             log.ThugLogging.Features.increase_html_count()
 
-    def handle_head(self, head):
+    def handle_head(self, head): # pylint:disable=unused-argument
         if log.ThugOpts.features_logging:
             log.ThugLogging.Features.increase_head_count()
 
-    def handle_title(self, title):
+    def handle_title(self, title): # pylint:disable=unused-argument
         if log.ThugOpts.features_logging:
             log.ThugLogging.Features.increase_title_count()
 
-    def handle_body(self, body):
+    def handle_body(self, body): # pylint:disable=unused-argument
         if log.ThugOpts.features_logging:
             log.ThugLogging.Features.increase_body_count()
 
@@ -868,12 +886,12 @@ class DFT:
 
             if name.lower() in ('input', ):
                 if payload is None:
-                    payload = dict()
+                    payload = {}
 
                 if all(p in child.attrs for p in ('name', 'value', )):
                     payload[child.attrs['name']] = child.attrs['value']
 
-        headers = dict()
+        headers = {}
         headers['Content-Type'] = 'application/x-www-form-urlencoded'
 
         try:
@@ -882,7 +900,7 @@ class DFT:
                                                     method = method.upper(),
                                                     body = payload,
                                                     redirect_type = "form")
-        except Exception as e: # pragma: no cover
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.info("[ERROR][do_handle_form] %s", str(e))
             return
 
@@ -917,7 +935,7 @@ class DFT:
         if log.ThugOpts.features_logging:
             log.ThugLogging.Features.increase_url_count()
 
-        headers = dict()
+        headers = {}
 
         embed_type = embed.get('type', None)
         if embed_type:
@@ -932,7 +950,7 @@ class DFT:
 
         try:
             self.window._navigator.fetch(src, headers = headers, redirect_type = "embed")
-        except Exception as e:
+        except Exception as e: # pylint:disable=broad-except
             log.info("[ERROR][handle_embed] %s", str(e))
 
     def handle_applet(self, applet):
@@ -947,7 +965,7 @@ class DFT:
         if log.ThugOpts.features_logging:
             log.ThugLogging.Features.increase_url_count()
 
-        headers = dict()
+        headers = {}
         headers['Connection']   = 'keep-alive'
         headers['Content-type'] = 'application/x-java-archive'
 
@@ -959,7 +977,7 @@ class DFT:
                                          headers = headers,
                                          redirect_type = "applet",
                                          params = params)
-        except Exception as e: # pragma: no cover
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.info("[ERROR][handle_applet] %s", str(e))
 
     def handle_meta(self, meta):
@@ -969,7 +987,7 @@ class DFT:
         if name and name.lower() in ('generator', ):
             content = meta.get('content', None)
             if content:
-                log.ThugLogging.add_behavior_warn("[Meta] Generator: %s" % (content, ))
+                log.ThugLogging.add_behavior_warn(f"[Meta] Generator: {content}")
 
         self.handle_meta_http_equiv(meta)
 
@@ -983,7 +1001,7 @@ class DFT:
             return
 
         tag = http_equiv.lower().replace('-', '_')
-        handler = getattr(self, 'handle_meta_{}'.format(tag), None)
+        handler = getattr(self, f'handle_meta_{tag}', None)
         if handler:
             handler(http_equiv, content) # pylint:disable=not-callable
 
@@ -1027,7 +1045,7 @@ class DFT:
 
         for s in content.split(';'):
             if data_uri is True and url is not None:
-                url = "{};{}".format(url, s)
+                url = f"{url};{s}"
 
             s = s.strip()
             if s.lower().startswith('url='):
@@ -1048,7 +1066,7 @@ class DFT:
 
         try:
             response = self.window._navigator.fetch(url, redirect_type = "meta")
-        except Exception as e:
+        except Exception as e: # pylint:disable=broad-except
             log.info("[ERROR][handle_meta_refresh] %s", str(e))
             return
 
@@ -1095,7 +1113,7 @@ class DFT:
 
         try:
             response = self.window._navigator.fetch(src, redirect_type = redirect_type)
-        except Exception as e:
+        except Exception as e: # pylint:disable=broad-except
             log.info("[ERROR][handle_frame] %s", str(e))
             return
 
@@ -1148,7 +1166,7 @@ class DFT:
 
             try:
                 self.window._navigator.fetch(url, redirect_type = "font face")
-            except Exception as e:
+            except Exception as e: # pylint:disable=broad-except
                 log.info("[ERROR][do_handle_font_face_rule] %s", str(e))
                 return
 
@@ -1159,7 +1177,7 @@ class DFT:
 
         try:
             sheet = cssparser.parseString(style.encode_contents())
-        except Exception as e: # pragma: no cover
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.info("[ERROR][handle_style] %s", str(e))
             return
 
@@ -1185,7 +1203,7 @@ class DFT:
         Explorer requires that the charset's specification must precede the
         base64 token.
         """
-        uri = uri if isinstance(uri, six.string_types) else str(uri)
+        uri = uri if isinstance(uri, str) else str(uri)
         if not uri.lower().startswith("data:"):
             return None
 
@@ -1204,10 +1222,10 @@ class DFT:
         if 'base64' in opts:
             try:
                 data = base64.b64decode(h[1])
-            except Exception: # pragma: no cover
+            except Exception: # pragma: no cover,pylint:disable=broad-except
                 try:
-                    data = base64.b64decode(urlparse.unquote(h[1]))
-                except Exception:
+                    data = base64.b64decode(unquote(h[1]))
+                except Exception: # pylint:disable=broad-except
                     log.warning("[WARNING] Error while handling data URI: %s", data)
                     return None
 
@@ -1251,7 +1269,7 @@ class DFT:
 
         try:
             response = self.window._navigator.fetch(href, redirect_type = "anchor")
-        except Exception as e: # pragma: no cover
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.info("[ERROR][handle_a] %s", str(e))
             return
 
@@ -1286,7 +1304,7 @@ class DFT:
 
         try:
             self.window._navigator.fetch(href, redirect_type = "link")
-        except Exception as e:
+        except Exception as e: # pylint:disable=broad-except
             log.info("[ERROR][handle_link] %s", str(e))
 
     def handle_img(self, img):
@@ -1315,7 +1333,7 @@ class DFT:
 
         try:
             self.window._navigator.fetch(src, redirect_type = "img")
-        except Exception as e: # pragma: no cover
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.info("[ERROR][handle_img] %s", str(e))
 
     def check_anchors(self):
@@ -1357,8 +1375,8 @@ class DFT:
         handler = None
 
         try:
-            handler = getattr(self, "handle_%s" % (str(name.lower()), ), None)
-        except Exception as e: # pragma: no cover
+            handler = getattr(self, f"handle_{str(name.lower())}", None)
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.warning("[ERROR][do_handle] %s", str(e))
 
         child._soup = soup
@@ -1400,14 +1418,14 @@ class DFT:
 
             try:
                 value = int(attrs[key].split('px')[0])
-            except Exception:
+            except Exception: # pylint:disable=broad-except
                 value = None
 
             if not value:
                 continue
 
             if value <= 2:
-                m = getattr(log.ThugLogging.Features, 'increase_{}_small_{}_count'.format(tagname, key), None)
+                m = getattr(log.ThugLogging.Features, f'increase_{tagname}_small_{key}_count', None)
                 if m:
                     m()
 
@@ -1415,14 +1433,14 @@ class DFT:
             element_area *= value
 
         if attrs_count > 1 and element_area < 30:
-            m = getattr(log.ThugLogging.Features, 'increase_{}_small_area_count'.format(tagname), None)
+            m = getattr(log.ThugLogging.Features, f'increase_{tagname}_small_area_count', None)
             if m:
                 m()
 
     def run_htmlclassifier(self, soup):
         try:
             log.HTMLClassifier.classify(log.ThugLogging.url if log.ThugOpts.local else self.window.url, str(soup))
-        except Exception as e: # pragma: no cover
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.info("[ERROR][run_htmlclassifier] %s", str(e))
 
     def _run(self, soup = None):
@@ -1488,21 +1506,21 @@ class DFT:
             try:
                 self.handle_window_event(evt)
                 self.run_htmlclassifier(soup)
-            except Exception: # pragma: no cover
+            except Exception: # pragma: no cover,pylint:disable=broad-except
                 log.warning("[handle_events] Event %s not properly handled", evt)
 
         for evt in self.handled_on_events:
             try:
                 self.handle_document_event(evt)
                 self.run_htmlclassifier(soup)
-            except Exception: # pragma: no cover
+            except Exception: # pragma: no cover,pylint:disable=broad-except
                 log.warning("[handle_events] Event %s not properly handled", evt)
 
         for evt in self.handled_events:
             try:
                 self.handle_element_event(evt)
                 self.run_htmlclassifier(soup)
-            except Exception: # pragma: no cover
+            except Exception: # pragma: no cover,pylint:disable=broad-except
                 log.warning("[handle_events] Event %s not properly handled", evt)
 
     def run(self):
