@@ -9,7 +9,7 @@ log = logging.getLogger("Thug")
 
 class CSSStyleDeclaration(JSClass):
     def __init__(self, style):
-        self.props = dict()
+        self.props = {}
 
         for prop in [p for p in style.split(';') if p]:
             k, v = prop.strip().split(':')
@@ -17,7 +17,7 @@ class CSSStyleDeclaration(JSClass):
 
     @property
     def cssText(self):
-        css_text = '; '.join(["%s: %s" % (k, v) for k, v in self.props.items()])
+        css_text = '; '.join([f"{k}: {v}" for k, v in self.props.items()])
         return css_text + ';' if css_text else ''
 
     def getPropertyValue(self, name):
