@@ -25,8 +25,10 @@ import numbers
 import collections.abc
 import datetime
 import random
-import six.moves.urllib_parse as urllib
-import six
+import types
+
+from urllib.parse import unquote
+
 import bs4
 
 from thug.ActiveX.ActiveX import _ActiveXObject
@@ -78,7 +80,7 @@ class Window(JSClass):
 
             try:
                 sched.run()
-            except Exception as e: # pragma: no cover
+            except Exception as e: # pragma: no cover,pylint:disable=broad-except
                 log.warning("[Timer] Scheduler error: %s", str(e))
 
         def stop(self):
@@ -100,8 +102,8 @@ class Window(JSClass):
                         self.code()
                     else:
                         ctx.eval(self.code)
-                except Exception as e: # pragma: no cover
-                    log.warning("Error while handling timer callback")
+                except Exception as e: # pragma: no cover,pylint:disable=broad-except
+                    log.warning("Error while handling timer callback (%s)", str(e))
 
                     if log.ThugOpts.Personality.isIE():
                         raise TypeError() from e
@@ -200,16 +202,16 @@ class Window(JSClass):
         finally:
             self._symbols.discard(key)
 
-        if log.JSEngine.isJSFunction(symbol):
+        if log.JSEngine.isJSFunction(symbol): # pragma: no cover
             _method = None
             if _method is None:
-                _method = six.create_bound_method(symbol, Window)
+                _method = types.MethodType(symbol, Window)
 
             setattr(self, key, _method)
             context.locals[key] = _method
             return _method
 
-        _types = (six.string_types,
+        _types = (str,
                   bool,
                   numbers.Number,
                   datetime.datetime)
@@ -332,6 +334,10 @@ class Window(JSClass):
         return self._screen_top
 
     def _do_ActiveXObject(self, cls, typename = 'name'):
+        if cls.lower() in ('htmlfile', ):
+            setattr(self.doc, "Script", self)
+            return self.doc
+
         return _ActiveXObject(self, cls, typename)
 
     def alert(self, text):
@@ -363,7 +369,7 @@ class Window(JSClass):
 
         None.
         """
-        pass
+        log.warning('[Window] back()')
 
     def blur(self):
         """
@@ -376,7 +382,7 @@ class Window(JSClass):
 
         None.
         """
-        pass
+        log.warning('[Window] blur()')
 
     def captureEvents(self, eventType):
         """
@@ -389,7 +395,7 @@ class Window(JSClass):
 
         eventType is a string
         """
-        self.alert("[Captured Event] %s" % (eventType, ))
+        self.alert(f"[Captured Event] {eventType}")
 
     def clearInterval(self, intervalID):
         """
@@ -460,7 +466,7 @@ class Window(JSClass):
 
         None.
         """
-        pass
+        log.warning('[Window] focus()')
 
     def forward(self):
         """
@@ -486,9 +492,9 @@ class Window(JSClass):
 
         None.
         """
-        pass
+        log.warning('[Window] GetAttention()')
 
-    def getSelection(self):
+    def getSelection(self): # pylint:disable=useless-return
         """
         Returns the selection (generally text).
         Syntax
@@ -499,6 +505,7 @@ class Window(JSClass):
 
         selection is a selection object.
         """
+        log.warning('[Window] getSelection()')
         return None
 
     def home(self):
@@ -526,7 +533,7 @@ class Window(JSClass):
         deltaX is the amount of pixels to move the window horizontally.
         deltaY is the amount of pixels to move the window vertically.
         """
-        pass
+        log.warning('[Window] moveBy(%s, %s)', deltaX, deltaY)
 
     def moveTo(self, x, y):
         """
@@ -540,7 +547,7 @@ class Window(JSClass):
         x is the horizontal coordinate to be moved to.
         y is the vertical coordinate to be moved to.
         """
-        pass
+        log.warning('[Window] moveTo(%s, %s)', x, y)
 
     def prompt(self, text, defaultText = None):
         """
@@ -560,7 +567,7 @@ class Window(JSClass):
 
         eventType is a string
         """
-        self.alert("[Released Event] %s" % (eventType, ))
+        self.alert(f"[Released Event] {eventType}")
 
     def resizeBy(self, xDelta, yDelta):
         """
@@ -574,7 +581,7 @@ class Window(JSClass):
         xDelta is the number of pixels to grow the window horizontally.
         yDelta is the number of pixels to grow the window vertically.
         """
-        pass
+        log.warning('[Window] resizeBy(%s, %s)', xDelta, yDelta)
 
     def resizeTo(self, iWidth, iHeight):
         """
@@ -588,7 +595,7 @@ class Window(JSClass):
         iWidth is an integer representing the new width in pixels.
         iHeight is an integer value representing the new height in pixels.
         """
-        pass
+        log.warning('[Window] resizeTo(%s, %s)', iWidth, iHeight)
 
     def scroll(self, x, y):
         """
@@ -604,7 +611,7 @@ class Window(JSClass):
         y-coord is the pixel along the vertical axis of the document that you
         want displayed in the upper left.
         """
-        pass
+        log.warning('[Window] scroll(%s, %s)', x, y)
 
     def scrollBy(self, xDelta, yDelta):
         """
@@ -619,7 +626,7 @@ class Window(JSClass):
 
         yDelta is the amount of pixels to scroll vertically.
         """
-        pass
+        log.warning('[Window] scrollBy(%s, %s)', xDelta, yDelta)
 
     def scrollByLines(self, lines):
         """
@@ -632,7 +639,7 @@ class Window(JSClass):
 
         lines is the number of lines.
         """
-        pass
+        log.warning('[Window] scrollByLines(%s)', lines)
 
     def scrollByPages(self, pages):
         """
@@ -645,7 +652,7 @@ class Window(JSClass):
 
         pages is the number of pages to scroll.
         """
-        pass
+        log.warning('[Window] scrollByPages(%s)', pages)
 
     def scrollTo(self, x, y):
         """
@@ -662,7 +669,7 @@ class Window(JSClass):
         y-coord is the pixel along the vertical axis of the document that you
         want displayed in the upper left.
         """
-        pass
+        log.warning('[Window] scrollTo(%s, %s)', x, y)
 
     def setInterval(self, f, delay, lang = 'JavaScript'):
         """
@@ -739,9 +746,9 @@ class Window(JSClass):
 
         None.
         """
-        pass
+        log.warning('[Window] stop()')
 
-    def _attachEvent(self, sEvent, fpNotify, useCapture = False):
+    def _attachEvent(self, sEvent, fpNotify, useCapture = False): # pylint:disable=unused-argument
         if log.ThugOpts.features_logging:
             log.ThugLogging.Features.increase_attachevent_count()
 
@@ -758,22 +765,22 @@ class Window(JSClass):
         if notify in (fpNotify, ):
             delattr(self, sEvent.lower())
 
-    def _addEventListener(self, _type, listener, useCapture = False):
+    def _addEventListener(self, _type, listener, useCapture = False): # pylint:disable=unused-argument
         if log.ThugOpts.features_logging:
             log.ThugLogging.Features.increase_addeventlistener_count()
 
-        setattr(self, 'on%s' % (_type.lower(), ), listener)
+        setattr(self, f"on{_type.lower()}", listener)
 
-    def _removeEventListener(self, _type, listener, useCapture = False):
+    def _removeEventListener(self, _type, listener, useCapture = False): # pylint:disable=unused-argument
         if log.ThugOpts.features_logging:
             log.ThugLogging.Features.increase_removeeventlistener_count()
 
-        _listener = getattr(self, 'on%s' % (_type.lower(), ), None)
+        _listener = getattr(self, f"on{_type.lower()}", None)
         if _listener is None: # pragma: no cover
             return
 
         if _listener in (listener, ):
-            delattr(self, 'on%s' % (_type.lower(), ))
+            delattr(self, f"on{_type.lower()}")
 
     def _CollectGarbage(self):
         pass
@@ -782,7 +789,7 @@ class Window(JSClass):
         self.location = location
         return 0
 
-    def _execScript(self, code, language = "JScript"):
+    def _execScript(self, code, language = "JScript"): # pylint:disable=useless-return
         if log.ThugOpts.code_logging:
             log.ThugLogging.add_code_snippet(code, language, 'Contained_Inside')
 
@@ -953,7 +960,7 @@ class Window(JSClass):
 
             if log.ThugOpts.code_logging:
                 log.ThugLogging.add_code_snippet(script, 'Javascript', 'Contained_Inside')
-        except Exception as e: # pragma: no cover
+        except Exception as e: # pragma: no cover,pylint:disable=broad-except
             log.warning("[Window] JSClassifier error: %s", str(e))
 
         if tag:
@@ -961,7 +968,7 @@ class Window(JSClass):
         else:
             try:
                 body = self.doc.body
-            except Exception: # pragma: no cover
+            except Exception: # pragma: no cover,pylint:disable=broad-except
                 # This code is for when you are desperate :)
                 body = self.doc.getElementsByTagName('body')[0]
 
@@ -990,7 +997,7 @@ class Window(JSClass):
 
         # %xx format
         if '%' in s and '%u' not in s:
-            return urllib.unquote(s)
+            return unquote(s)
 
         # %uxxxx format
         while i < len(s):
@@ -1019,7 +1026,7 @@ class Window(JSClass):
         """
         The atob method decodes a base-64 encoded string
         """
-        if isinstance(s, six.string_types):
+        if isinstance(s, str):
             s = s.encode()
 
         return base64.b64decode(s)
@@ -1028,15 +1035,15 @@ class Window(JSClass):
         """
         The btoa method encodes a string in base-64
         """
-        if isinstance(s, six.string_types):
+        if isinstance(s, str):
             s = s.encode()
 
         return base64.b64encode(s)
 
     def decodeURIComponent(self, s):
-        return urllib.unquote(s) if s else ""
+        return unquote(s) if s else ""
 
-    def Image(self, width = 800, height = 600):
+    def Image(self, width = 800, height = 600): # pylint:disable=unused-argument
         return self.doc.createElement('img')
 
     def _XMLHttpRequest(self):
@@ -1054,17 +1061,17 @@ class Window(JSClass):
 
             try:
                 self._navigator.fetch(rootFolder, redirect_type = "Sharepoint")
-            except Exception:
+            except Exception: # pylint:disable=broad-except
                 log.warning(traceback.format_exc())
 
-    def getComputedStyle(self, element, pseudoelt = None):
+    def getComputedStyle(self, element, pseudoelt = None): # pylint:disable=unused-argument
         if log.ThugOpts.features_logging:
             log.ThugLogging.Features.increase_getcomputedstyle_count()
 
         return getattr(element, 'style', None)
 
     def open(self, url = None, name = '_blank', specs = '', replace = False):
-        if url and not isinstance(url, six.string_types): # pragma: no cover
+        if url and not isinstance(url, str): # pragma: no cover
             url = str(url)
 
         if url and url not in ('about:blank', ):
@@ -1073,7 +1080,7 @@ class Window(JSClass):
 
             try:
                 response = self._navigator.fetch(url, redirect_type = "window open")
-            except Exception:
+            except Exception: # pylint:disable=broad-except
                 return None
 
             if response is None or not response.ok: # pragma: no cover
@@ -1086,7 +1093,7 @@ class Window(JSClass):
 
             try:
                 log.HTMLClassifier.classify(log.ThugLogging.url if log.ThugOpts.local else url, html)
-            except Exception as e: # pragma: no cover
+            except Exception as e: # pragma: no cover,pylint:disable=broad-except
                 log.warning("[Window] HTMLClassifier error: %s", str(e))
 
             content_type = response.headers.get('content-type' , None)
